package com.phm.manage.service.impl;

import com.phm.manage.domain.AfterAnalysisResult;
import com.phm.manage.mapper.AfterAnalysisResultMapper;
import com.phm.manage.service.IAfterAnalysisResultService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 维修测试控制解析后数据Service业务层处理
 *
 * @author phm
 * @date 2023-08-22
 */
@Service
public class AfterAnalysisResultServiceImpl implements IAfterAnalysisResultService {
    @Autowired
    private AfterAnalysisResultMapper afterAnalysisResultMapper;

    /**
     * 查询维修测试控制解析后数据
     *
     * @param id 维修测试控制解析后数据主键
     * @return 维修测试控制解析后数据
     */
    @Override
    public AfterAnalysisResult selectAfterAnalysisResultById(Long id) {
        return afterAnalysisResultMapper.selectAfterAnalysisResultById(id);
    }

    /**
     * 查询维修测试控制解析后数据列表
     *
     * @param afterAnalysisResult 维修测试控制解析后数据
     * @return 维修测试控制解析后数据
     */
    @Override
    public List<AfterAnalysisResult> selectAfterAnalysisResultList(AfterAnalysisResult afterAnalysisResult) {
        return afterAnalysisResultMapper.selectAfterAnalysisResultList(afterAnalysisResult);
    }

    /**
     * 新增维修测试控制解析后数据
     *
     * @param afterAnalysisResult 维修测试控制解析后数据
     * @return 结果
     */
    @Override
    public int insertAfterAnalysisResult(AfterAnalysisResult afterAnalysisResult) {
        return afterAnalysisResultMapper.insertAfterAnalysisResult(afterAnalysisResult);
    }

    /**
     * 修改维修测试控制解析后数据
     *
     * @param afterAnalysisResult 维修测试控制解析后数据
     * @return 结果
     */
    @Override
    public int updateAfterAnalysisResult(AfterAnalysisResult afterAnalysisResult) {
        return afterAnalysisResultMapper.updateAfterAnalysisResult(afterAnalysisResult);
    }

    /**
     * 批量删除维修测试控制解析后数据
     *
     * @param ids 需要删除的维修测试控制解析后数据主键
     * @return 结果
     */
    @Override
    public int deleteAfterAnalysisResultByIds(Long[] ids) {
        return afterAnalysisResultMapper.deleteAfterAnalysisResultByIds(ids);
    }

    /**
     * 删除维修测试控制解析后数据信息
     *
     * @param id 维修测试控制解析后数据主键
     * @return 结果
     */
    @Override
    public int deleteAfterAnalysisResultById(Long id) {
        return afterAnalysisResultMapper.deleteAfterAnalysisResultById(id);
    }
}
